.. include:: readme.rst
.. include:: download.rst
.. include:: img_read.rst
.. include:: img2ts.rst
.. include:: ts_read.rst
.. include:: variables_era5
.. include:: variables_era5land

Contents
========

.. toctree::
   :maxdepth: 2

   Download <download>
   Image Reading <img_read>
   Time Series Creation <img2ts>
   Time Series Reading <ts_read>
   All variables available for ERA5 <variables_era5>
   All variables available for ERA5-Land <variables_era5land>
   License <license>
   Authors <authors>
   Changelog <changelog>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
